==> pulsar-client-admin-original-2.7.2.1-rc-202105140121-sources.jar: org/apache/pulsar/client/admin/internal/http/AsyncHttpConnectorProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.admin.internal.http;

import javax.ws.rs.client.Client;
import javax.ws.rs.core.Configuration;

import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
import org.glassfish.jersey.client.spi.Connector;
import org.glassfish.jersey.client.spi.ConnectorProvider;

/**
 * Admin specific Jersey client connector provider.
 */
public class AsyncHttpConnectorProvider implements ConnectorProvider {

    private final ClientConfigurationData conf;
    private Connector connector;

    public AsyncHttpConnectorProvider(ClientConfigurationData conf) {
        this.conf = conf;
    }

    @Override
    public Connector getConnector(Client client, Configuration runtimeConfig) {
        if (connector == null) {
            connector = new AsyncHttpConnector(client, conf);
        }
        return connector;
    }


    public AsyncHttpConnector getConnector(int connectTimeoutMs, int readTimeoutMs, int requestTimeoutMs) {
        return new AsyncHttpConnector(connectTimeoutMs, readTimeoutMs, requestTimeoutMs, conf);
    }
}

==> pulsar-client-admin-original-2.10.3-sources.jar: org/apache/pulsar/client/admin/internal/http/AsyncHttpConnectorProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.admin.internal.http;

import javax.ws.rs.client.Client;
import javax.ws.rs.core.Configuration;
import org.apache.pulsar.client.impl.conf.ClientConfigurationData;
import org.glassfish.jersey.client.spi.Connector;
import org.glassfish.jersey.client.spi.ConnectorProvider;

/**
 * Admin specific Jersey client connector provider.
 */
public class AsyncHttpConnectorProvider implements ConnectorProvider {

    private final ClientConfigurationData conf;
    private Connector connector;
    private final int autoCertRefreshTimeSeconds;

    public AsyncHttpConnectorProvider(ClientConfigurationData conf, int autoCertRefreshTimeSeconds) {
        this.conf = conf;
        this.autoCertRefreshTimeSeconds = autoCertRefreshTimeSeconds;
    }

    @Override
    public Connector getConnector(Client client, Configuration runtimeConfig) {
        if (connector == null) {
            connector = new AsyncHttpConnector(client, conf, autoCertRefreshTimeSeconds);
        }
        return connector;
    }


    public AsyncHttpConnector getConnector(int connectTimeoutMs, int readTimeoutMs, int requestTimeoutMs,
            int autoCertRefreshTimeSeconds) {
        return new AsyncHttpConnector(connectTimeoutMs, readTimeoutMs, requestTimeoutMs, autoCertRefreshTimeSeconds,
                conf);
    }
}
